@@ -1,6 +1,6 @@
 package SPVM::Sys;
 
-our $VERSION = "0.508";
+our $VERSION = "0.509";
 
 1;
 
@@ -16,69 +16,484 @@ The Sys class of L<SPVM> has methods to call system calls for file IO, sockets,
 
   use Sys;
   
+  my $fd_ref = [(Sys::IO::FileStream)undef];
+  Sys->open($fd_ref, "<", $path);
+  
   Sys->mkdir("foo");
   
   Sys->rmdir("foo");
   
   my $path = Sys->env("PATH");
   
-  my $process_id = Sys->getpid;
+  my $process_id = Sys->process_id;
 
 =head1 Class Methods
 
-=head2 env
+=head2 STDIN
 
-C<static method env : string ($name : string);>
+C<static method STDIN : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
 
-Gets an environment variable with the name $name.
+Returns the L<stdin|SPVM::Document::NativeAPI/"spvm_stdin"> opened by the SPVM language.
 
-=head2 set_env
+=head2 STDOUT
 
-C<static method set_env : void ($name : string, $value : string);>
+C<static method STDOUT : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
 
-Sets an environment variable with the name $name and the value $value.
+Returns the L<stdout|SPVM::Document::NativeAPI/"spvm_stdout"> opened by the SPVM language.
 
-If $value is undef or "", the environment variable is removed.
+=head2 STDERR
+
+C<static method STDERR : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
+
+Returns the L<stderr|SPVM::Document::NativeAPI/"spvm_stderr"> opened by the SPVM language.
+
+=head2 open
+
+C<static method open : void ($stream_ref : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>[], $open_mode : string, $file_name : string);>
+
+Opens a file given the open mode $open_mode and the file name $file_name. 
+
+The opened file stream is set to $stream_ref at index 0.
+
+The open mode $open_mode is replaced to a representation of the L<fopen|https://linux.die.net/man/3/fopen> function before calling the L<fopen|https://linux.die.net/man/3/fopen> function.
+
+  [$open_mode]   [The mode of the fopen function]
+  <              rb
+  >              wb
+  >>             wa
+  +<             r+b
+  +>             w+b
+  +>>            a+b
+
+If available, C<FD_CLOEXEC> is set to the file descriptor of the opened file stream.
 
 Exceptions:
 
-This method calls the following methods, so exceptions thrown by these methods could be thrown.
+$stream_ref must be defined. Otherwise an exception is thrown.
 
-=over 2
+The length of $stream_ref must be equal to 1. Otherwise an exception is thrown.
 
-=item * L<_putenv_s|SPVM::Sys::Env/"_putenv_s"> in Sys::Env
+Exceptions thrown by the L<fopen|SPVM::Sys::IO/"fopen"> method in the Sys::IO class could be thrown.
 
-=item * L<setenv|SPVM::Sys::Env/"setenv"> in Sys::Env
+=head2 fdopen
 
-=item * L<unsetenv|SPVM::Sys::Env/"unsetenv"> in Sys::Env
+C<static method fdopen : void ($stream_ref : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>[], $open_mode : string, $fd : int);>
 
-=back
+Same as L</"open"> method except that this method takes the file descriptor $fd instead of the file name .
 
-=head2 osname
+=head2 fileno
 
-C<static method osname : string ()>
+C<static method fileno : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
-Gets the OS name. This method corresponds to Perl's L<$^O|https://perldoc.perl.org/perlvar#$%5EO>.
+Return the file descriptor of the file stream $stream.
 
-=over 2
+Exceptions:
 
-=item * C<linux>
+Exceptions thrown by the L<fileno|SPVM::Sys::IO/"fileno"> method in the Sys::IO class could be thrown.
 
-=item * C<darwin>
+=head2 read
 
-=item * C<MSWin32>
+C<static method read : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $buf : mutable string, $length : int, $buf_offset : int = 0);>
 
-=item * C<freebsd>
+Reads data from the file stream $stream by the $length, and saves it to the buffer $buf at offset $buf_offset.
 
-=item * C<openbsd>
+Exceptions:
 
-=item * C<solaris>
+Exceptions thrown by the L<fread|SPVM::Sys::IO/"fread"> method in the Sys::IO class could be thrown.
 
-=back
+=head2 eof
+
+C<static method eof : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
+
+Checks if the file stream $stream reasches the end of the file.
+
+If it does, returns 1, otherwise returns 0.
+
+Exceptions:
+
+Exceptions thrown by the L<feof|SPVM::Sys::IO/"feof"> method in the Sys::IO class could be thrown.
+
+=head2 readline
+
+C<static method readline : mutable string ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
+
+Reads a line from th file stream $stream and returns it.
+
+Exceptions:
+
+$stream must be defined.
+
+Exceptions thrown by the L</"getc"> method could be thrown.
+
+=head2 getc
+
+C<static method getc : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
+
+Gets a charactor from the file stream $stream and returns it.
+
+Exceptions:
+
+Exceptions thrown by the L<getc|SPVM::Sys::IO/"getc"> method in the Sys::IO class could be thrown.
+
+=head2 print
+
+C<static method print : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $string : string);>
+
+Prints the string $string to the file stream $stream.
+
+Exceptions:
+
+Exceptions thrown by the L<fwrite|SPVM::Sys::IO/"fwrite"> method in the Sys::IO class could be thrown.
+
+=head2 printf
+
+C<static method printf : void ($stream, $format : string, $args : object[])>
+
+Prints the format string $string given the arguments $args to the file stream $stream.
+
+Exceptions thrown by the L<"print"> method class could be thrown.
+
+=head2 say
+
+C<static method say : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $string : string);>
+
+Prints the string $string and "\n" to the file stream $stream.
+
+Exceptions:
+
+Exceptions thrown by the L<"print"> method class could be thrown.
+
+=head2 close
+
+C<static method close : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
+
+Closes the file stream $stream.
+
+Exceptions:
+
+Exceptions thrown by the L<fclose|SPVM::Sys::IO/"fclose"> method in the Sys::IO class could be thrown.
+
+=head2 seek
+
+C<static method seek : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $offset : long, $whence : int);>
+
+Moves the read/write position pointed to by the file stream $stream to the offset $offset given $whence.
+
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about constant values given to $whence.
+
+Exceptions:
+
+Exceptions thrown by the L<fseek|SPVM::Sys::IO/"fseek"> method in the Sys::IO class could be thrown.
+
+=head2 tell
+
+C<static method tell : long ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
+
+Returns the read/write position pointed to by the file stream $stream.
+
+Exceptions:
+
+Exceptions thrown by the L<ftell|SPVM::Sys::IO/"ftell"> method in the Sys::IO class could be thrown.
+
+=head2 sysopen
+
+C<static method sysopen : void ($fd_ref : int*, $path : string, $flags : int, $mode : int = 0);>
+
+Opens a file given, the file path $path, the mode $flags and the mode $mode.
+
+The file descriptor of the opened file is set to the value reffered by $fd_ref.
+
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about constant values given to the flags $flags and the mode $mode.
+
+Exceptions:
+
+Exceptions thrown by the L<open|SPVM::Sys::IO/"open"> method in the Sys::IO class could be thrown.
+
+=head2 sysread
+
+C<static method sysread : int ($fd : int, $buf : mutable string, $length : int, $buf_offset : int = 0);>
+
+Reads data from the file stream $stream by the $length, and saves it to the buffer $buf from the offset $buf_offset.
+
+Exceptions:
+
+Exceptions thrown by the L<read|SPVM::Sys::IO/"read"> method in the Sys::IO class could be thrown.
+
+=head2 syswrite
+
+C<static method syswrite : int ($fd : int, $buf : string, $length : int = -1, $buf_offset : int = 0);>
+
+Writes data to the file stream $stream by the $length from the buffer $buf at offset $buf_offset.
+
+Exceptions:
+
+Exceptions thrown by the L<write|SPVM::Sys::IO/"write"> method in the Sys::IO class could be thrown.
+
+=head2 sysseek
+
+C<static method sysseek : long ($fd : int, $offset : long, $whence : int);>
+
+Moves the read/write position pointed to by the file descriptor $fd to the offset $offset given $whence.
+
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about constant values given to $whence.
+
+Exceptions:
+
+Exceptions thrown by the L<lseek|SPVM::Sys::IO/"lseek"> method in the Sys::IO class could be thrown.
+
+=head2 fcntl
+
+C<static method fcntl : int ($fd : int, $command : int, $command_arg : object of Int|SPVM::Sys::IO::Flock|object = undef);>
+
+Calls the L<fcntl|SPVM::Sys::IO/"fcntl"> method in the Sys::IO class and its return value.
+
+Exceptions:
+
+Exceptions thrown by the L<fcntl|SPVM::Sys::IO/"fcntl"> method in the Sys::IO class could be thrown.
+
+=head2 flock
+
+C<static method flock : void ($fd : int, $operation : int);>
+
+Locks the file specified by the file descriptor $fd given the operation $operation.
+
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about constant values given to the operation $operation.
+
+Exceptions:
+
+Exceptions thrown by the L<flock|SPVM::Sys::IO/"flock"> method in the Sys::IO class could be thrown.
+
+=head2 mkdir
+
+C<static method mkdir : void ($path : string, $mode : int);>
+
+Creates the directory given the path $path and the mode $mode.
+
+The permissions of the created directory are ($mode & ~L<umask|/"umask"> & 0777).
+
+In Windows, the mode $mode is ignored.
+
+Exceptions:
+
+Exceptions thrown by the L<mkdir|SPVM::Sys::IO/"mkdir"> method in the Sys::IO class could be thrown.
+
+=head2 umask
+
+C<static method umask : int ($mode : int);>
+
+Sets the umask for the process to the mode $mode and returns the previous value.
+
+Exceptions:
+
+Exceptions thrown by the L<umask|SPVM::Sys::IO/"umask"> method in the Sys::IO class could be thrown.
+
+=head2 unlink
+
+C<static method unlink : void ($pathname : string);>
+
+Deletes a file.
+
+In Windows, this method calls the L<unlink|SPVM::Sys::IO::Windows/"unlink"> method in the Sys::IO::Windows, otherwise calls the L<unlink|SPVM::Sys::IO/"unlink"> method in the Sys::IO class.
+
+Exceptions:
+
+Exceptions thrown by the L<unlink|SPVM::Sys::IO::Windows/"unlink"> method or the L<unlink|SPVM::Sys::IO/"unlink"> method in the Sys::IO class could be thrown.
+
+=head2 rename
+
+C<static method rename : void ($oldpath : string, $newpath : string);>
+
+Raname the file name from the old name $oldpath to the new name $newpath.
+
+In Windows, this method calls the L<rename|SPVM::Sys::IO::Windows/"rename"> method in the Sys::IO::Windows, otherwise calls the L<rename|SPVM::Sys::IO/"rename"> method in the Sys::IO class.
+
+Exceptions:
+
+Exceptions thrown by the L<rename|SPVM::Sys::IO::Windows/"rename"> method or the L<rename|SPVM::Sys::IO/"rename"> method in the Sys::IO class could be thrown.
+
+=head2 rmdir
+
+C<static method rmdir : void ($path : string);>
+
+Deletes the directory given the path $path.
+
+Exceptions:
+
+Exceptions thrown by the L<rmdir|SPVM::Sys::IO/"rmdir"> method in the Sys::IO class could be thrown.
+
+=head2 chdir
+
+C<static method chdir : void ($path : string);>
+
+Changes the working directory to the path $path.
+
+Exceptions:
+
+Exceptions thrown by the L<chdir|SPVM::Sys::IO/"chdir"> method in the Sys::IO class could be thrown.
+
+=head2 chmod
+
+C<static method chmod : void ($mode :int, $path : string);>
+
+Changes the permissions of the file $path to the permission $mode.
+
+Exceptions:
+
+Exceptions thrown by the L<chmod|SPVM::Sys::IO/"chmod"> method in the Sys::IO class could be thrown.
+
+=head2 chown
+
+C<static method chown : void ($owner : int, $group : int, $path : string);>
+
+Changes the owner and the group of the file $path to $owner and $group.
+
+Exceptions:
+
+Exceptions thrown by the L<chown|SPVM::Sys::IO/"chown"> method in the Sys::IO class could be thrown.
+
+=head2 readlink
+
+C<static method readlink : int ($file : string);>
+
+Returns the content of the symbolic link file $file.
+
+In Windows thie method calls the L<readlink|SPVM::Sys::IO::Windows/"readlink"> method in the Sys::IO::Windows, otherwise calls the L<readlink|SPVM::Sys::IO/"readlink"> method in the Sys::IO.
+
+Exceptions:
+
+Exceptions thrown by the L<readlink|SPVM::Sys::IO/"readlink"> method in the Sys::IO or the L<readlink|SPVM::Sys::IO::Windows/"readlink"> method in the Sys::IO::Windows class could be thrown.
+
+=head2 symlink
+
+C<static method symlink : int ($oldpath : string, $newpath : string);>
+
+Creates a path $newpath symbolically linked to the path $oldpath.
+
+In Windows thie method calls the L<symlink|SPVM::Sys::IO::Windows/"symlink"> method in the Sys::IO::Windows, otherwise calls the L<symlink|SPVM::Sys::IO/"symlink"> method in the Sys::IO.
+
+Exceptions:
+
+Exceptions thrown by the L<symlink|SPVM::Sys::IO/"symlink"> method in the Sys::IO or the L<symlink|SPVM::Sys::IO::Windows/"symlink"> method in the Sys::IO::Windows class could be thrown.
+
+=head2 truncate
+
+C<static method truncate : void ($fd : int, $legnth : long);>
+
+Truncates the file referenced by the file descriptor $fd to a size of precisely length bytes $legnth.
+
+Exceptions:
+
+Exceptions thrown by the L<ftruncate|SPVM::Sys::IO/"ftruncate"> method in the Sys::IO class could be thrown.
+
+=head2 opendir
+
+C<static method opendir : void ($dh_ref : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>[], $dir : string);>
+
+Opens the directory stream given the directory $dir.
+
+The opened directory stream is set to $dh_ref at index 0.
+
+Exceptions:
+
+Exceptions thrown by the L<opendir|SPVM::Sys::IO/"opendir"> method in the Sys::IO class could be thrown.
+
+=head2 closedir
+
+C<static method closedir : void ($dstream : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
+
+Closes the directory stream given the directory $dstream.
+
+Exceptions:
+
+Exceptions thrown by the L<closedir|SPVM::Sys::IO/"closedir"> method in the Sys::IO class could be thrown.
+
+=head2 readdir
+
+C<static method readdir : L<Sys::IO::Dirent|SPVM::Sys::IO::Dirent> ($dstream : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
+
+Reads a directory entry from the dirctory stream $dstream.
+
+Exceptions:
+
+Exceptions thrown by the L<readdir|SPVM::Sys::IO/"readdir"> method in the Sys::IO class could be thrown.
+
+=head2 rewinddir
+
+C<static method rewinddir : void ($dstream : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
+
+Resets the position of the directory stream $dstream to the beginning of the directory.
+
+Exceptions:
+
+Exceptions thrown by the L<rewinddir|SPVM::Sys::IO/"rewinddir"> method in the Sys::IO class could be thrown.
+
+=head2 telldir
+
+C<static method telldir : long ($dstream : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
+
+Returns the current location associated with the directory stream $dstream.
+
+Exceptions:
+
+Exceptions thrown by the L<telldir|SPVM::Sys::IO/"telldir"> method in the Sys::IO class could be thrown.
+
+=head2 popen
+
+C<static method popen : void ($stream_ref : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>[], $open_mode : string, $command : string);>
+
+Opens a file stream that joins a process by creating a pipe given the command $command and the open mode $open_mode.
+
+The opened file stream is set to $stream_ref at index 0.
+
+The open mode $open_mode is replaced to a representation of the L<fopen|https://linux.die.net/man/3/fopen> function before calling the L<fopen|https://linux.die.net/man/3/fopen> function.
+
+  [$open_mode]   [The mode of the fopen function]
+  |-             wb
+  -|             rb
+
+Exceptions:
+
+Exceptions thrown by the L<popen|SPVM::Sys::IO/"popen"> method in the Sys::IO or the L<_popen|SPVM::Sys::IO/"_popen"> method in the Sys::IO class could be thrown.
+
+=head2 pclose
+
+C<static method pclose : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
+
+Closes the file stream $stream created by the L</"popen"> method.
+
+Exceptions:
+
+Exceptions thrown by the L<pclose|SPVM::Sys::IO/"pclose"> method in the Sys::IO or the L<_pclose|SPVM::Sys::IO/"_pclose"> method in the Sys::IO class could be thrown.
+
+=head2 select
+
+C<static method select : int ($readfds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $writefds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $exceptfds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $timeout : double = 0);>
+
+Calls the L<select|SPVM::Sys::Select/"select"> method in the Sys::Select class and returns its return value.
+
+If $timeout is greter than or equal to 0, it is converted to a L<Sys::Time::Timeval|SPVM::Sys::Time::Timeval> object. Otherwise is converted to undef.
+
+$nfds is set to 1024.
+
+Exceptions:
+
+Exceptions thrown by the L<select|SPVM::Sys::Select/"select"> method in the Sys::Select class method could be thrown.
+
+=head2 ioctl
+
+C<static method ioctl : int ($fd : int, $request : int, $request_arg_ref : object of byte[]|short[]|int[]|long[]|float[]|double[]|object = undef);>
+
+Windows:
+
+Calls the L<ioctlsocket|SPVM::Sys::Ioctl/"ioctlsocket"> method in the L<Sys::Ioctl|SPVM::Sys::Ioctl> class and returns its return value.
+
+OSs other than Windows:
+
+Calls the L<ioctl|SPVM::Sys::Ioctl/"ioctl"> method in the L<Sys::Ioctl|SPVM::Sys::Ioctl> class and returns its return value.
 
 Excetpions:
 
-If the OS name could not be determined, an exception is thrown.
+Excetpions thrown by the L<ioctl|SPVM::Sys::Ioctl/"ioctl"> method or the L<ioctlsocket|SPVM::Sys::Ioctl/"ioctlsocket"> method in the L<Sys::Ioctl|SPVM::Sys::Ioctl> class could be thrown.
 
 =head2 A
 
@@ -448,125 +863,87 @@ Exceptions thrown by the L<utime|SPVM::Sys::Time/"utime"> method in the Sys::Tim
 
 C<static method stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat> ($path : string);>
 
-Creates a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object and calls the L<stat||SPVM::Sys::IO::Stat/"stat"> method in the L<Sys::IO::Stat|SPVM::Sys::IO::Stat> class.
+Returns information about a file $path.
 
-And returns the a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
+Exceptions:
+
+Exceptions thrown by the L<stat|SPVM::Sys::IO::Stat/"stat"> method in the Sys::IO::Stat class could be thrown.
+
+=head2 lstat
+
+C<static method lstat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat> ($path : string);>
+
+Identical to L</"stat">, except that if path $path is a symbolic link(or directory junction only in Windows), then the link itself is stat-ed, not the file that it refers to.
+
+In Windows, this method calls the L<lstat|SPVM::Sys::IO::Windows/"lstat"> method, otherwise calls the L<lstat|SPVM::Sys::IO::Stat/"lstat"> method.
+
+Exceptions:
+
+Exceptions thrown by the L<lstat|SPVM::Sys::IO::Stat/"lstat"> method in the Sys::IO::Stat class or the L<lstat|SPVM::Sys::IO::Windows/"lstat"> method in the Sys::IO::Windows class could be thrown.
 
 =head2 fstat
 
 C<static method fstat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat> ($fd : int);>
 
-Creates a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object and calls the L<fstat||SPVM::Sys::IO::Stat/"fstat"> method in the L<Sys::IO::Stat|SPVM::Sys::IO::Stat> class.
+Identical to L</"stat">, except that the file to be stat-ed is specified by the file descriptor $fd.
 
-And returns the a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
+Exceptions:
 
-=head2 chdir
+Exceptions thrown by the L<fstat|SPVM::Sys::IO::Stat/"fstat"> method in the Sys::IO::Stat class could be thrown.
 
-C<static method chdir : void ($path : string);>
+=head2 env
 
-Changes the working directory to $path.
+C<static method env : string ($name : string);>
 
-=head2 chmod
+Gets an environment variable with the name $name.
 
-C<static method chmod : void ($mode :int, $path : string);>
+=head2 set_env
 
-Changes the permissions of a file.
+C<static method set_env : void ($name : string, $value : string);>
 
-=head2 mkdir
+Sets an environment variable with the name $name and the value $value.
 
-C<static method mkdir : void ($path : string, $mode : int);>
+If $value is undef or "", the environment variable is removed.
 
-Creates the directory specified by $path and $mode.
+Exceptions:
 
-=head2 umask
+This method calls the following methods, so exceptions thrown by these methods could be thrown.
 
-C<static method umask : int ($mode : int);>
+=over 2
 
-Sets the umask for the process to $mode and returns the previous value.
+=item * L<_putenv_s|SPVM::Sys::Env/"_putenv_s"> in Sys::Env
 
-=head2 rmdir
+=item * L<setenv|SPVM::Sys::Env/"setenv"> in Sys::Env
 
-C<static method rmdir : void ($path : string);>
+=item * L<unsetenv|SPVM::Sys::Env/"unsetenv"> in Sys::Env
 
-Deletes the directory specified by $path.
+=back
 
-=head2 opendir
+=head2 osname
 
-C<static method opendir : void ($dh_ref : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>[], $dir : string);>
+C<static method osname : string ()>
 
-Calls the L<opendir|SPVM::Sys::IO/"opendir"> method in the L<Sys::Socket|SPVM::Sys::Socket> class.
+Gets the OS name. This method corresponds to Perl's L<$^O|https://perldoc.perl.org/perlvar#$%5EO>.
 
-The return value is set to $dh_ref->[0].
+=over 2
 
-=head2 closedir
+=item * C<linux>
 
-C<static method closedir : void ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
+=item * C<darwin>
 
-Calls the L<closedir|SPVM::Sys::IO/"closedir"> method in the L<Sys::Socket|SPVM::Sys::Socket> class.
+=item * C<MSWin32>
 
-=head2 close
+=item * C<freebsd>
 
-C<static method close : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
+=item * C<openbsd>
 
-Calls the L<fclose|SPVM::Sys::IO/"fclose"> method in the L<Sys::Socket|SPVM::Sys::Socket> class.
+=item * C<solaris>
 
-If succedd, returns 1.
-
-=head2 unlink
-
-C<static method unlink : void ($pathname : string);>
-
-Deletes a file.
-
-=head2 rename
-
-C<static method rename : void ($oldpath : string, $newpath : string);>
-
-Changes the name of a file.
-
-=head2 readlink
-
-C<static method readlink : int ($file : string);>
-
-Returns the value of a symbolic link.
-
-=head2 symlink
-
-C<static method symlink : int ($oldpath : string, $newpath : string);>
-
-Creates a $newpath symbolically linked to $oldpath.
-
-=head2 sleep
-
-C<static method sleep : int ($seconds : int);>
-
-Causes the program to sleep for $seconds seconds.
-
-=head2 ioctl
-
-C<static method ioctl : int ($fd : int, $request : int, $request_arg_ref : object of byte[]|short[]|int[]|long[]|float[]|double[]|object = undef);>
-
-Windows:
-
-Calls the L<ioctlsocket|SPVM::Sys::Ioctl/"ioctlsocket"> method in the L<Sys::Ioctl|SPVM::Sys::Ioctl> class and returns its return value.
-
-OSs other than Windows:
-
-Calls the L<ioctl|SPVM::Sys::Ioctl/"ioctl"> method in the L<Sys::Ioctl|SPVM::Sys::Ioctl> class and returns its return value.
+=back
 
 Excetpions:
 
-Excetpions thrown by the L<ioctl|SPVM::Sys::Ioctl/"ioctl"> method or the L<ioctlsocket|SPVM::Sys::Ioctl/"ioctlsocket"> method in the L<Sys::Ioctl|SPVM::Sys::Ioctl> class could be thrown.
-
-=head2 select
-
-C<static method select : int ($readfds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $writefds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $exceptfds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $timeout : double = 0);>
-
-Calls the L<select|SPVM::Sys::Select/"select"> method in the Sys::Select class and returns its return value.
-
-If $timeout is greter than or equal to 0, it is converted to a L<Sys::Time::Timeval|SPVM::Sys::Time::Timeval> object. Otherwise it becomes undef.
-
-$nfds is set to 1024.
+If the OS name could not be determined, an exception is thrown.
 
 =head2 bind
 
@@ -689,228 +1066,6 @@ A string for the next argument $optval is created by the length $optlen.
 Calls the L<getsockopt|SPVM::Sys::Socket/"getsockopt"> method in the L<Sys::Socket|SPVM::Sys::Socket> class
 with $optval and $optlen, and $optval set by this method is returnd.
 
-=head2 truncate
-
-C<static method truncate : void ($fd : int, $legnth : long);>
-
-Calls the L<ftruncate|SPVM::Sys::IO/"ftruncate"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 sysread
-
-C<static method sysread : int ($fd : int, $buf : mutable string, $count : int, $buf_offset : int = 0);>
-
-Calls the L<read|SPVM::Sys::IO/"read"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 syswrite
-
-C<static method syswrite : int ($fd : int, $buf : string, $count : int = -1, $buf_offset : int = 0);>
-
-Calls the L<write|SPVM::Sys::IO/"write"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 eof
-
-C<static method eof : int ($stream : L<Sys::IO::Stream|SPVM::Sys::IO::Stream>);>
-
-Calls the L<feof|SPVM::Sys::IO/"feof"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 fileno
-
-C<static method fileno : int ($stream : L<Sys::IO::Stream|SPVM::Sys::IO::Stream>);>
-
-Calls the L<fileno|SPVM::Sys::IO/"fileno"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 readline
-
-C<static method readline : mutable string ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
-
-Calls the L<readline|SPVM::Sys::IO/"readline"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 getc
-
-C<static method getc : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
-
-Calls the L<getc|SPVM::Sys::IO/"getc"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 flock
-
-C<static method flock : void ($fd : int, $operation : int);>
-
-Calls the L<flock|SPVM::Sys::IO/"flock"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 print
-
-C<static method print : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $string : string);>
-
-Calls the L<fwrite|SPVM::Sys::IO/"fwrite"> method in the L<Sys::IO|SPVM::Sys::IO> class given the length of $string.
-
-=head2 printf
-
-C<static method printf : void ($stream, $format : string, $args : object[])>
-
-Calls the L</"print"> method after creating formatted string given $stream and $args using the L<sprintf|SPVM::Format/"sprintf"> method in the L<Format|SPVM::Format> class.
-
-=head2 read
-
-C<static method read : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $buf : mutable string, $count : int, $buf_offset : int = 0);>
-
-Calls the L<fread|SPVM::Sys::IO/"fread"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 rewinddir
-
-C<static method rewinddir : void ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
-
-Calls the L<rewinddir|SPVM::Sys::IO/"rewinddir"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 readdir
-
-C<static method readdir : L<Sys::IO::Dirent|SPVM::Sys::IO::Dirent> ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
-
-Calls the L<readdir|SPVM::Sys::IO/"readdir"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 seek
-
-C<static method seek : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $offset : long, $whence : int);>
-
-Calls the L<fseek|SPVM::Sys::IO/"fseek"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 sysseek
-
-C<static method sysseek : long ($fd : int, $offset : long, $whence : int);>
-
-Calls the L<lseek|SPVM::Sys::IO/"lseek"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 tell
-
-C<static method tell : long ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
-
-Calls the L<ftell|SPVM::Sys::IO/"ftell"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 telldir
-
-C<static method telldir : long ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
-
-Calls the L<telldir|SPVM::Sys::IO/"telldir"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 lstat
-
-C<static method lstat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat> ($path : string);>
-
-Creates a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object and calls the L<lstat|SPVM::Sys::IO::Stat/"lstat"> method in the L<Sys::IO::Stat|SPVM::Sys::IO::Stat> class.
-
-And returns the a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
-
-=head2 chown
-
-C<static method chown : void ($owner : int, $group : int, $path : string);>
-
-Calls the L<chown|SPVM::Sys::IO/"chown"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 fcntl
-
-C<static method fcntl : int ($fd : int, $command : int, $command_arg : object of Int|Sys::IO::Flock|object = undef);>
-
-Calls the L<fcntl|SPVM::Sys::IO/"fcntl"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 STDIN
-
-C<static method STDIN : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
-
-Returns the stdin opened by the SPVM language.
-
-=head2 STDOUT
-
-C<static method STDOUT : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
-
-Returns the stdout opened by the SPVM language.
-
-=head2 STDERR
-
-C<static method STDERR : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
-
-Returns the stderr opened by the SPVM language.
-
-=head2 open
-
-C<static method open : void ($stream_ref : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>[], $open_mode : string, $file_name : string);>
-
-$open_mode is replaced by the following logic.
-
-  if ($open_mode eq "<") {
-    $open_mode = "rb";
-  }
-  elsif ($open_mode eq ">") {
-    $open_mode = "wb";
-  }
-  elsif ($open_mode eq ">>") {
-    $open_mode = "wa";
-  }
-  elsif ($open_mode eq "+<") {
-    $open_mode = "r+b";
-  }
-  elsif ($open_mode eq "+>") {
-    $open_mode = "w+b";
-  }
-  elsif ($open_mode eq "+>>") {
-    $open_mode = "a+b";
-  }
-
-Calls the L<fopen|SPVM::Sys::IO/"fopen"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-The return values is set to $stream_ref->[0].
-
-Exceptions:
-
-$stream_ref must be defined. Otherwise an exception is thrown.
-
-The length of \$stream_ref must be equal to 1. Otherwise an exception is thrown.
-
-=head2 fdopen
-
-C<static method fdopen : void ($stream_ref : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>[], $open_mode : string, $fd : int);>
-
-$open_mode is replaced by the following logic.
-
-  if ($open_mode eq "<") {
-    $open_mode = "rb";
-  }
-  elsif ($open_mode eq ">") {
-    $open_mode = "wb";
-  }
-  elsif ($open_mode eq ">>") {
-    $open_mode = "wa";
-  }
-  elsif ($open_mode eq "+<") {
-    $open_mode = "r+b";
-  }
-  elsif ($open_mode eq "+>") {
-    $open_mode = "w+b";
-  }
-  elsif ($open_mode eq "+>>") {
-    $open_mode = "a+b";
-  }
-
-Calls the L<fdopen|SPVM::Sys::IO/"fdopen"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-The return values is set to $stream_ref->[0].
-
-Exceptions:
-
-$stream_ref must be defined. Otherwise an exception is thrown.
-
-The length of \$stream_ref must be equal to 1. Otherwise an exception is thrown.
-
-=head2 sysopen
-
-C<static method sysopen : void ($fd_ref : int*, $path : string, $flags : int, $mode : int = 0);>
-
-Calls the L<open|SPVM::Sys::IO/"open"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 say
-
-C<static method say : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $string : string);>
-
-Calls the L</"print"> method adding C<\n> to the end of $string.
-
 =head2 signal
 
 C<static method signal : void ($signum : int, $handler_name : string);>
@@ -959,14 +1114,6 @@ Exceptions:
 
 The exceptions thrown by the L<alarm|SPVM::Sys::Signal/"alarm"> method in the Sys::Signal class could be thrown.
 
-=head2 popen
-
-C<static method popen : void ($stream_ref : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>[], $open_mode : string, $command : string);>
-
-=head2 pclose
-
-C<static method pclose : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
-
 =head2 fork
 
 C<static method fork : int ();>
