@@ -13,14 +13,14 @@ static const char* FILE_NAME = "Sys/Time/Tms.c";
 
 int32_t SPVM__Sys__Time__Tms__new(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "The new method in the Sys::Time::Tms is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The new method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
   int32_t error_id = 0;
   
   struct tms* st_tms = env->new_memory_block(env, stack, sizeof(struct tms));
-
+  
   void* obj_st_tms = env->new_pointer_object_by_name(env, stack, "Sys::Time::Tms", st_tms, &error_id, __func__, FILE_NAME, __LINE__);
   if (error_id) { return error_id; }
   
@@ -32,7 +32,7 @@ int32_t SPVM__Sys__Time__Tms__new(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "The DESTROY method in the Sys::Time::Tms is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The DESTROY method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -40,10 +40,8 @@ int32_t SPVM__Sys__Time__Tms__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   struct tms* st_tms = env->get_pointer(env, stack, obj_self);
   
-  if (st_tms) {
-    env->free_memory_block(env, stack, st_tms);
-    env->set_pointer(env, stack, obj_self, NULL);
-  }
+  env->free_memory_block(env, stack, st_tms);
+  env->set_pointer(env, stack, obj_self, NULL);
   
   return 0;
 #endif
@@ -51,7 +49,7 @@ int32_t SPVM__Sys__Time__Tms__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__tms_utime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "The tms_utime method in the Sys::Time::Tms is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The tms_utime method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -59,12 +57,7 @@ int32_t SPVM__Sys__Time__Tms__tms_utime(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   struct tms* st_tms = env->get_pointer(env, stack, obj_self);
   
-  if (st_tms) {
-    stack[0].lval = st_tms->tms_utime;
-  }
-  else {
-    assert(0);
-  }
+  stack[0].lval = st_tms->tms_utime;
   
   return 0;
 #endif
@@ -72,20 +65,15 @@ int32_t SPVM__Sys__Time__Tms__tms_utime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__set_tms_utime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "The set_tms_utime method in the Sys::Time::Tms is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The set_tms_utime method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_self = stack[0].oval;
   
   struct tms* st_tms = env->get_pointer(env, stack, obj_self);
   
-  if (st_tms) {
-    int64_t tms_utime = stack[1].lval;
-    st_tms->tms_utime = tms_utime;
-  }
-  else {
-    assert(0);
-  }
+  int64_t tms_utime = stack[1].lval;
+  st_tms->tms_utime = tms_utime;
   
   return 0;
 #endif
@@ -93,7 +81,7 @@ int32_t SPVM__Sys__Time__Tms__set_tms_utime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__tms_stime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "The tms_stime method in the Sys::Time::Tms is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The tms_stime method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -101,12 +89,7 @@ int32_t SPVM__Sys__Time__Tms__tms_stime(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   struct tms* st_tms = env->get_pointer(env, stack, obj_self);
   
-  if (st_tms) {
-    stack[0].lval = st_tms->tms_stime;
-  }
-  else {
-    assert(0);
-  }
+  stack[0].lval = st_tms->tms_stime;
   
   return 0;
 #endif
@@ -114,20 +97,15 @@ int32_t SPVM__Sys__Time__Tms__tms_stime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__set_tms_stime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "The set_tms_stime method in the Sys::Time::Tms is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The set_tms_stime method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_self = stack[0].oval;
   
   struct tms* st_tms = env->get_pointer(env, stack, obj_self);
   
-  if (st_tms) {
-    int64_t tms_stime = stack[1].lval;
-    st_tms->tms_stime = tms_stime;
-  }
-  else {
-    assert(0);
-  }
+  int64_t tms_stime = stack[1].lval;
+  st_tms->tms_stime = tms_stime;
   
   return 0;
 #endif
@@ -135,7 +113,7 @@ int32_t SPVM__Sys__Time__Tms__set_tms_stime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__tms_cutime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "The tms_cutime method in the Sys::Time::Tms is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The tms_cutime method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -143,12 +121,7 @@ int32_t SPVM__Sys__Time__Tms__tms_cutime(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   struct tms* st_tms = env->get_pointer(env, stack, obj_self);
   
-  if (st_tms) {
-    stack[0].lval = st_tms->tms_cutime;
-  }
-  else {
-    assert(0);
-  }
+  stack[0].lval = st_tms->tms_cutime;
   
   return 0;
 #endif
@@ -156,20 +129,15 @@ int32_t SPVM__Sys__Time__Tms__tms_cutime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__set_tms_cutime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "The set_tms_cutime method in the Sys::Time::Tms is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The set_tms_cutime method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_self = stack[0].oval;
   
   struct tms* st_tms = env->get_pointer(env, stack, obj_self);
   
-  if (st_tms) {
-    int64_t tms_cutime = stack[1].lval;
-    st_tms->tms_cutime = tms_cutime;
-  }
-  else {
-    assert(0);
-  }
+  int64_t tms_cutime = stack[1].lval;
+  st_tms->tms_cutime = tms_cutime;
   
   return 0;
 #endif
@@ -177,7 +145,7 @@ int32_t SPVM__Sys__Time__Tms__set_tms_cutime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__tms_cstime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "The tms_cstime method in the Sys::Time::Tms is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The tms_cstime method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   
@@ -185,12 +153,7 @@ int32_t SPVM__Sys__Time__Tms__tms_cstime(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   struct tms* st_tms = env->get_pointer(env, stack, obj_self);
   
-  if (st_tms) {
-    stack[0].lval = st_tms->tms_cstime;
-  }
-  else {
-    assert(0);
-  }
+  stack[0].lval = st_tms->tms_cstime;
   
   return 0;
 #endif
@@ -198,20 +161,15 @@ int32_t SPVM__Sys__Time__Tms__tms_cstime(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Time__Tms__set_tms_cstime(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(_WIN32)
-  env->die(env, stack, "The set_tms_cstime method in the Sys::Time::Tms is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "The set_tms_cstime method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_self = stack[0].oval;
   
   struct tms* st_tms = env->get_pointer(env, stack, obj_self);
   
-  if (st_tms) {
-    int64_t tms_cstime = stack[1].lval;
-    st_tms->tms_cstime = tms_cstime;
-  }
-  else {
-    assert(0);
-  }
+  int64_t tms_cstime = stack[1].lval;
+  st_tms->tms_cstime = tms_cstime;
   
   return 0;
 #endif
